@@ -36,7 +36,7 @@ mkdir 'out' 'inst' || exit 1
 
 
 (
-	cp -r 'buildsrc' 'build'
+	cp -rp 'buildsrc' 'build'
 	cd "${BUILDDIR}" || exit 1
 
 	# Fix up archives that Tcl gets wrong
@@ -70,18 +70,18 @@ mkdir 'out' 'inst' || exit 1
 	mkdir "starpack.vfs"
 	mkdir "starpack.vfs/lib"
 
-	## Copy in all built directories
-	cp -r "${OTHERPKGSDIR}"/*/out/* 'starpack.vfs/'
-
-	## Rename the "vfs" package directory to what "boot.tcl" expects
-	mv 'starpack.vfs/lib'/vfs* 'starpack.vfs/lib/vfs'
-
 	## Install "boot.tcl"
 	cp 'boot.tcl' 'starpack.vfs/'
 
 	## Install "tclkit.ico"
 	cp 'tclkit.ico' 'starpack.vfs/'
 
+	## Copy in all built directories
+	cp -r "${OTHERPKGSDIR}"/*/out/* 'starpack.vfs/'
+
+	## Rename the "vfs" package directory to what "boot.tcl" expects
+	mv 'starpack.vfs/lib'/vfs* 'starpack.vfs/lib/vfs'
+
 	# Figure out if zlib compiled (if not, the system zlib will be used and we
 	# will need to have that present)
 	ZLIBDIR="$(cd "${OTHERPKGSDIR}/zlib/inst" 2>/dev/null && pwd)"
@@ -100,14 +100,16 @@ mkdir 'out' 'inst' || exit 1
 	export EXTRA_OBJS
 
 	## Tk Resources (needed for Win32 support) -- remove kit-found resources to prevent the symbols from being in conflict
-	TKDIR="$(cd "${OTHERPKGSDIR}/tk/inst" && pwd)"
-	TKRSRC="${TKDIR}/lib/tkbase.res.o"
-	if [ -n "${TKDIR}" -a -f "${TKRSRC}" ]; then
-		EXTRA_OBJS="${EXTRA_OBJS} ${TKRSRC}"
+	TKDIR="$(cd "${OTHERPKGSDIR}/tk/inst" 2>/dev/null && pwd)"
+	if [ -n "${TKDIR}" ]; then
+		TKRSRC="${TKDIR}/lib/tkbase.res.o"
+		if [ -f "${TKRSRC}" ]; then
+			EXTRA_OBJS="${EXTRA_OBJS} ${TKRSRC}"
 
-		echo ' *** Removing "kit.rc" since we have Tk with its own resource file'
+			echo ' *** Removing "kit.rc" since we have Tk with its own resource file'
 
-		rm -f "${BUILDDIR}/kit.rc"
+			rm -f "${BUILDDIR}/kit.rc"
+		fi
 	fi
 
 	# Cleanup
